Surgex.Parser.StringParser (Surgex v6.0.1)
View SourceAvailable options:
- trim is trimming whitespaces from the string, takes priority over min and max options
- min is a minimal length of the string, returns :too_short error symbol
- max is a maximal length of the string, returns :too_long error symbol
- regex - input string must match passed regular expression, this is done after trimming